.. Copyright 2016 IBM Corp. All Rights Reserved.
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
..    http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..

.. _`Tutorial`:

Tutorial
========

This is a short tutorial about using the zhmcclient package.

Python code examples this tutorial are shown using
`Jupyter Notebooks <jupyter-notebook-beginner-guide.readthedocs.io/>`_
(formerly known as IPython Notebooks), using the online
`Jupyter Notebook Viewer <http://nbviewer.jupyter.org/>`_.
This allows viewing them without having Jupyter installed locally.

In order to run or modify the examples, Jupyter Notebook must be installed,
and a running WBEM server should be available.

The following table lists the available tutorials:

======================================================== ==================================
View the tutorial                                        Download the Jupyter notebook
======================================================== ==================================
:nbview:`Making Connections <connections.ipynb>`         :nbdown:`connections.ipynb`
:nbview:`Python Data Model <datamodel.ipynb>`            :nbdown:`datamodel.ipynb`
======================================================== ==================================

